@@ -25,6 +25,7 @@
 #' @param wind logical value. if TRUE, please set coliwd, coliws.
 #' @param coliws numeric value, column index of wind speed in dataframe.
 #' @param coliwd numeric value, column index of wind direction (degree) in dataframe.
+#' @param sn logical value. if TRUE, the results will be presented by scientific notation (string).
 #' @return  a list with 2 dataframe (average and SD). The first column of dataframe is the serial number within the period. The
 #' average variation (or SD) start from the second column. \cr
 #' Note that when the pattern USES
@@ -32,16 +33,16 @@
 #' element in the average variation. For example, if the first timestamp of data is
 #' "2010-05-01 12:00:00", the resolution is 1 hour, the mode is "ncycle", and the
 #' value is 24, then the result represents diurnal variation starting from 12 o'clock.
-
+#'
 #' @export
 #' @examples
 #' avri(met, bkip = "1 hour", mode = "recipes", value = "day",
 #' st = "2017-05-01 00:00:00", wind = TRUE, coliws = 4, coliwd = 5)
-#' @importFrom dplyr full_join
+#' @importFrom dplyr full_join left_join
 #' @importFrom stats aggregate
 #' @importFrom lubridate duration
 
-avri<-function(df, bkip=NULL, mode = "recipes", value = "day", st = NULL, et = NULL, na.rm = TRUE, digits = 2, wind = FALSE, coliws = 2, coliwd = 3){
+avri<-function(df, bkip=NULL, mode = "recipes", value = "day", st = NULL, et = NULL, na.rm = TRUE, digits = 2, wind = FALSE, coliws = 2, coliwd = 3, sn=FALSE){
 
   #time resampling
   if(mode!="custom"){
@@ -83,7 +84,7 @@ avri<-function(df, bkip=NULL, mode = "recipes", value = "day", st = NULL, et = N
       mod_list=month(rs_df[,1])
     }
   }else if(mode=="ncycle"){
-    mod_list=seq(0,nrow(rs_df)-1,1)%%value
+    mod_list=seq(0,nrow(rs_df)-1,1)%%as.numeric(value)
   }else if(mode=="custom"){
     mod_list=rs_df[,1]
   }
@@ -125,18 +126,34 @@ avri<-function(df, bkip=NULL, mode = "recipes", value = "day", st = NULL, et = N
   #format average data (avoid NA)
   if(!all(is.na(results[, -1]))){
 	if(ncol(results)==2){
-		results[,-1]=do.call(rbind, lapply(results[,-1], formatC, format = "e", digits = digits))
+		if(sn==TRUE){
+			results[,-1]=do.call(rbind, lapply(results[,-1], formatC, format = "e", digits = digits))
+		}else{
+			results[,-1]=do.call(rbind, lapply(results[,-1], as.numeric))
+		}
 	}else{
-		results[,-1]=lapply(results[,-1], formatC, format = "e", digits = digits)
+		if(sn==TRUE){
+			results[,-1]=lapply(results[,-1], formatC, format = "e", digits = digits)
+		}else{
+			results[,-1]=lapply(results[,-1], as.numeric)
+		}
 	}
   }
 
   #format sd data (avoid NA)
   if(!all(is.na(results_sd[, -1]))){
 	if(ncol(results_sd)==2){
-		results_sd[,-1]=do.call(rbind, lapply(results_sd[,-1], formatC, format = "e", digits = digits))
+		if(sn==TRUE){
+			results_sd[,-1]=do.call(rbind, lapply(results_sd[,-1], formatC, format = "e", digits = digits))
+		}else{
+			results_sd[,-1]=do.call(rbind, lapply(results_sd[,-1], as.numeric))
+		}
 	}else{
-		results_sd[,-1]=lapply(results_sd[,-1], formatC, format = "e", digits = digits)
+		if(sn==TRUE){	
+			results_sd[,-1]=lapply(results_sd[,-1], formatC, format = "e", digits = digits)
+		}else{
+			results_sd[,-1]=lapply(results_sd[,-1], as.numeric)
+		}
 	}
   }
 
@@ -170,6 +187,8 @@ avri<-function(df, bkip=NULL, mode = "recipes", value = "day", st = NULL, et = N
   #output
   df_average=results
   df_sd=results_sd
-  results <- list(df_average = df_average, df_sd = df_sd)
+  names(df_average)[-1]=paste0(names(df)[-1],"_ave")
+  names(df_sd)[-1]=paste0(names(df)[-1],"_sd")
+  results=left_join(df_average, df_sd, by = names(df_average)[1])
   return(results)
 }
